@@ -3,7 +3,8 @@ import yaml
 import importlib
 from fastapi import FastAPI
 from .decorators import router, expose_api
-import uvicorn
+import asyncio
+from uvicorn import Config, Server
 
 def discover_manifests(root_dir: str = "."):
     """Encontra todos os manifest.yaml a partir de root_dir."""
@@ -36,6 +37,11 @@ def build_app():
 # instância global que uvicorn irá expor
 app = build_app()
 
-def main():
+async def main():
     port = int(os.getenv("PORT", 8000))
-    uvicorn.run("squad_builder_sdk.api.cli:app", host="0.0.0.0", port=port, reload=False)
+    config = Config("squad_builder.api.cli:app", host="0.0.0.0", port=port, reload=False)
+    server = Server(config)
+    await server.serve()
+
+if __name__ == "__main__":
+    asyncio.run(main())
